reveal.js - Ligthbox

## Preview Overlays

##### Images

Preview with default settings:
Preview with data-preview-fit="contain"
Preview with data-preview-fit="cover"
Preview another image (c)
Preview image from a link.

##### Videos

Preview video
Preview video
Preview video from a link.

##### Iframes

https://hakim.se | data-preview-link https://hakim.se | data-preview-link
https://hakim.se | data-preview-link=false
Preview link from an image

## Lightbox

##### Images

##### Videos

##### Iframes

https://hakim.se